App Store Connect Api
====

This is Python a wrapper around the Apple App Store Api : https://developer.apple.com/documentation/appstoreconnectapi

So far, it only handles token generation / expiration and defines a few routes.